@@ -1,6 +1,6 @@
 /*
    This file is part of the BOLT-LMM linear mixed model software package
-   developed by Po-Ru Loh.  Copyright (C) 2014-2018 Harvard University.
+   developed by Po-Ru Loh.  Copyright (C) 2014-2019 Harvard University.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@
 #include "FileUtils.hpp"
 #include "NumericUtils.hpp"
 #include "LDscoreCalibration.hpp"
+#include "LapackConst.hpp"
 
 
 using namespace LMM;
@@ -53,13 +54,13 @@ int main(int argc, char *argv[]) {
 
   cout << "                      +-----------------------------+" << endl;
   cout << "                      |                       ___   |" << endl;
-  cout << "                      |   BOLT-LMM, v2.3.2   /_ /   |" << endl;
-  cout << "                      |   March 10, 2018      /_/   |" << endl;
+  cout << "                      |   BOLT-LMM, v2.3.4   /_ /   |" << endl;
+  cout << "                      |   August 10, 2019     /_/   |" << endl;
   cout << "                      |   Po-Ru Loh            //   |" << endl;
   cout << "                      |                        /    |" << endl;
   cout << "                      +-----------------------------+" << endl;
   cout << endl;
-  cout << "Copyright (C) 2014-2018 Harvard University." << endl;
+  cout << "Copyright (C) 2014-2019 Harvard University." << endl;
   cout << "Distributed under the GNU GPLv3 open source license." << endl << endl;
 
 #ifdef VERBOSE
@@ -114,6 +115,9 @@ int main(int argc, char *argv[]) {
 
   cout << "Setting number of threads to " << params.numThreads << endl;
   omp_set_num_threads(params.numThreads);
+#ifdef USE_MKL
+  mkl_set_num_threads(params.numThreads);
+#endif
   
   cout << "fam: " << params.famFile << endl;
   cout << "bim(s): ";
@@ -652,6 +656,9 @@ int main(int argc, char *argv[]) {
   if (LINREGinflationEst > 1 && params.verboseStats)
     cout << "Note that LINREG may be confounded by a factor of " << LINREGinflationEst << endl;
 
+  /***** FREE GENOTYPES STORED IN RAM (NO LONGER NEEDED) *****/
+  snpData.freeGenotypes();
+
   /***** COMPUTE STATS AT FULL SET OF SNPS (INCLUDING NON-GRM SNPS) *****/
 
   // write stats to file
